@@ -9,7 +9,6 @@ bundled with tmuxp. Usage example:
 ...     from tmuxp._internal.types import PluginConfigSchema
 ...
 """
-import typing as t
 
 from typing_extensions import NotRequired, TypedDict
 
@@ -18,10 +17,10 @@ class PluginConfigSchema(TypedDict):
     plugin_name: NotRequired[str]
     tmux_min_version: NotRequired[str]
     tmux_max_version: NotRequired[str]
-    tmux_version_incompatible: NotRequired[t.List[str]]
+    tmux_version_incompatible: NotRequired[list[str]]
     libtmux_min_version: NotRequired[str]
     libtmux_max_version: NotRequired[str]
-    libtmux_version_incompatible: NotRequired[t.List[str]]
+    libtmux_version_incompatible: NotRequired[list[str]]
     tmuxp_min_version: NotRequired[str]
     tmuxp_max_version: NotRequired[str]
-    tmuxp_version_incompatible: NotRequired[t.List[str]]
+    tmuxp_version_incompatible: NotRequired[list[str]]
