@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 """Log utilities for tmuxp."""
+
 import logging
 import time
 import typing as t
@@ -134,7 +135,7 @@ class LogFormatter(logging.Formatter):
 
 
 def debug_log_template(
-    self: t.Type[logging.Formatter],
+    self: type[logging.Formatter],
     record: logging.LogRecord,
     stylized: t.Optional[bool] = False,
     **kwargs: t.Any,
@@ -192,9 +193,7 @@ def debug_log_template(
         + "%(lineno)d"
     )
 
-    tpl = reset + levelname + asctime + name + module_funcName + lineno + reset
-
-    return tpl
+    return reset + levelname + asctime + name + module_funcName + lineno + reset
 
 
 class DebugLogFormatter(LogFormatter):
