@@ -1,4 +1,5 @@
 """Workspace hydration and loading for tmuxp."""
+
 import logging
 import os
 import pathlib
@@ -25,7 +26,7 @@ def expandshell(value: str) -> str:
     return os.path.expandvars(os.path.expanduser(value))  # NOQA: PTH111
 
 
-def expand_cmd(p: t.Dict[str, t.Any]) -> t.Dict[str, t.Any]:
+def expand_cmd(p: dict[str, t.Any]) -> dict[str, t.Any]:
     """Resolve shell variables and expand shorthands in a tmuxp config mapping."""
     if isinstance(p, str):
         p = {"shell_command": [p]}
@@ -63,10 +64,10 @@ def expand_cmd(p: t.Dict[str, t.Any]) -> t.Dict[str, t.Any]:
 
 
 def expand(
-    workspace_dict: t.Dict[str, t.Any],
+    workspace_dict: dict[str, t.Any],
     cwd: t.Optional[t.Union[pathlib.Path, str]] = None,
     parent: t.Optional[t.Any] = None,
-) -> t.Dict[str, t.Any]:
+) -> dict[str, t.Any]:
     """Resolve workspace variables and expand shorthand style / inline properties.
 
     This is necessary to keep the code in the :class:`WorkspaceBuilder` clean
@@ -185,7 +186,7 @@ def expand(
     return workspace_dict
 
 
-def trickle(workspace_dict: t.Dict[str, t.Any]) -> t.Dict[str, t.Any]:
+def trickle(workspace_dict: dict[str, t.Any]) -> dict[str, t.Any]:
     """Return a dict with "trickled down" / inherited workspace values.
 
     This will only work if workspace has been expanded to full form with
@@ -217,15 +218,14 @@ def trickle(workspace_dict: t.Dict[str, t.Any]) -> t.Dict[str, t.Any]:
             session_start_directory = session_start_directory
             if "start_directory" not in window_dict:
                 window_dict["start_directory"] = session_start_directory
-            else:
-                if not any(
-                    window_dict["start_directory"].startswith(a) for a in ["~", "/"]
-                ):
-                    window_start_path = (
-                        pathlib.Path(session_start_directory)
-                        / window_dict["start_directory"]
-                    )
-                    window_dict["start_directory"] = str(window_start_path)
+            elif not any(
+                window_dict["start_directory"].startswith(a) for a in ["~", "/"]
+            ):
+                window_start_path = (
+                    pathlib.Path(session_start_directory)
+                    / window_dict["start_directory"]
+                )
+                window_dict["start_directory"] = str(window_start_path)
 
         # We only need to trickle to the window, workspace builder checks wconf
         if suppress_history is not None and "suppress_history" not in window_dict:
