@@ -1,9 +1,9 @@
 """CLI tests for tmuxp convert."""
+
 import contextlib
 import io
 import json
 import pathlib
-import typing as t
 
 import pytest
 
@@ -21,7 +21,7 @@ from tmuxp import cli
     ],
 )
 def test_convert(
-    cli_args: t.List[str],
+    cli_args: list[str],
     tmp_path: pathlib.Path,
     monkeypatch: pytest.MonkeyPatch,
 ) -> None:
@@ -31,7 +31,7 @@ def test_convert(
     if filename == ".":
         filename = ".tmuxp.yaml"
     file_ext = filename.rsplit(".", 1)[-1]
-    assert file_ext in ["yaml", "yml"], file_ext
+    assert file_ext in {"yaml", "yml"}, file_ext
     workspace_file_path = tmp_path / filename
     workspace_file_path.write_text("\nsession_name: hello\n", encoding="utf-8")
     oh_my_zsh_path = tmp_path / ".oh-my-zsh"
@@ -61,7 +61,7 @@ def test_convert(
     ],
 )
 def test_convert_json(
-    cli_args: t.List[str],
+    cli_args: list[str],
     tmp_path: pathlib.Path,
     monkeypatch: pytest.MonkeyPatch,
 ) -> None:
