@@ -1,19 +1,18 @@
 """CLI tests for tmuxp import."""
+
 import contextlib
 import io
 import pathlib
-import typing as t
 
 import pytest
 
+from tests.fixtures import utils as test_utils
 from tmuxp import cli
 
-from ..fixtures import utils as test_utils
-
 
 @pytest.mark.parametrize("cli_args", [(["import"])])
 def test_import(
-    cli_args: t.List[str],
+    cli_args: list[str],
     tmp_path: pathlib.Path,
     monkeypatch: pytest.MonkeyPatch,
     capsys: pytest.CaptureFixture[str],
@@ -26,7 +25,7 @@ def test_import(
 
 
 @pytest.mark.parametrize(
-    "cli_args,inputs",
+    ("cli_args", "inputs"),
     [
         (
             ["import", "teamocil", "./.teamocil/config.yaml"],
@@ -43,8 +42,8 @@ def test_import(
     ],
 )
 def test_import_teamocil(
-    cli_args: t.List[str],
-    inputs: t.List[str],
+    cli_args: list[str],
+    inputs: list[str],
     tmp_path: pathlib.Path,
     monkeypatch: pytest.MonkeyPatch,
 ) -> None:
@@ -73,7 +72,7 @@ def test_import_teamocil(
 
 
 @pytest.mark.parametrize(
-    "cli_args,inputs",
+    ("cli_args", "inputs"),
     [
         (
             ["import", "tmuxinator", "./.tmuxinator/config.yaml"],
@@ -90,8 +89,8 @@ def test_import_teamocil(
     ],
 )
 def test_import_tmuxinator(
-    cli_args: t.List[str],
-    inputs: t.List[str],
+    cli_args: list[str],
+    inputs: list[str],
     tmp_path: pathlib.Path,
     monkeypatch: pytest.MonkeyPatch,
 ) -> None:
