@@ -1,4 +1,5 @@
 """CLI tests for tmuxp load."""
+
 import contextlib
 import io
 import pathlib
@@ -11,6 +12,8 @@ from libtmux.server import Server
 from libtmux.session import Session
 from pytest_mock import MockerFixture
 
+from tests.constants import FIXTURE_PATH
+from tests.fixtures import utils as test_utils
 from tmuxp import cli
 from tmuxp._internal.config_reader import ConfigReader
 from tmuxp.cli.load import (
@@ -22,9 +25,6 @@ from tmuxp.cli.load import (
 from tmuxp.workspace import loader
 from tmuxp.workspace.builder import WorkspaceBuilder
 
-from ..constants import FIXTURE_PATH
-from ..fixtures import utils as test_utils
-
 
 def test_load_workspace(
     server: "Server",
@@ -174,8 +174,8 @@ windows:
         detached=True,
     )
     assert session is not None
-    assert session.attached_window is not None
-    pane = session.attached_window.attached_pane
+    assert session.active_window is not None
+    pane = session.active_window.active_pane
 
     assert isinstance(session, Session)
     assert session.name == "samplesimple"
@@ -187,7 +187,7 @@ windows:
 if t.TYPE_CHECKING:
     from typing_extensions import TypeAlias
 
-    ExpectedOutput: TypeAlias = t.Optional[t.Union[str, t.List[str]]]
+    ExpectedOutput: TypeAlias = t.Optional[t.Union[str, list[str]]]
 
 
 class CLILoadFixture(t.NamedTuple):
@@ -197,9 +197,9 @@ class CLILoadFixture(t.NamedTuple):
     test_id: str
 
     # test params
-    cli_args: t.List[t.Union[str, t.List[str]]]
-    config_paths: t.List[str]
-    session_names: t.List[str]
+    cli_args: list[t.Union[str, list[str]]]
+    config_paths: list[str]
+    session_names: list[str]
     expected_exit_code: int
     expected_in_out: "ExpectedOutput" = None
     expected_not_in_out: "ExpectedOutput" = None
@@ -207,7 +207,7 @@ class CLILoadFixture(t.NamedTuple):
     expected_not_in_err: "ExpectedOutput" = None
 
 
-TEST_LOAD_FIXTURES: t.List[CLILoadFixture] = [
+TEST_LOAD_FIXTURES: list[CLILoadFixture] = [
     CLILoadFixture(
         test_id="dir-relative-dot-samedir",
         cli_args=["load", "."],
@@ -294,9 +294,9 @@ def test_load(
     capsys: pytest.CaptureFixture[str],
     monkeypatch: pytest.MonkeyPatch,
     test_id: str,
-    cli_args: t.List[str],
-    config_paths: t.List[str],
-    session_names: t.List[str],
+    cli_args: list[str],
+    config_paths: list[str],
+    session_names: list[str],
     expected_exit_code: int,
     expected_in_out: "ExpectedOutput",
     expected_not_in_out: "ExpectedOutput",
@@ -362,7 +362,7 @@ def test_regression_00132_session_name_with_dots(
     [["load", ".", "-d"], ["load", ".tmuxp.yaml", "-d"]],
 )
 def test_load_zsh_autotitle_warning(
-    cli_args: t.List[str],
+    cli_args: list[str],
     tmp_path: pathlib.Path,
     monkeypatch: pytest.MonkeyPatch,
     capsys: pytest.CaptureFixture[str],
@@ -422,7 +422,7 @@ def test_load_zsh_autotitle_warning(
     ],
 )
 def test_load_log_file(
-    cli_args: t.List[str],
+    cli_args: list[str],
     tmp_path: pathlib.Path,
     monkeypatch: pytest.MonkeyPatch,
     capsys: pytest.CaptureFixture[str],
@@ -478,7 +478,7 @@ def test_load_plugins(
 
 @pytest.mark.skip("Not sure how to clean up the tmux session this makes")
 @pytest.mark.parametrize(
-    "cli_args,inputs",
+    ("cli_args", "inputs"),
     [
         (
             ["load", "tests/fixtures/workspace/builder/plugin_versions_fail.yaml"],
@@ -488,8 +488,8 @@ def test_load_plugins(
 )
 def test_load_plugins_version_fail_skip(
     monkeypatch_plugin_test_packages: None,
-    cli_args: t.List[str],
-    inputs: t.List[str],
+    cli_args: list[str],
+    inputs: list[str],
     capsys: pytest.CaptureFixture[str],
 ) -> None:
     """Test tmuxp load with plugins failing version constraints can continue."""
@@ -502,7 +502,7 @@ def test_load_plugins_version_fail_skip(
 
 
 @pytest.mark.parametrize(
-    "cli_args,inputs",
+    ("cli_args", "inputs"),
     [
         (
             ["load", "tests/fixtures/workspace/builder/plugin_versions_fail.yaml"],
@@ -512,8 +512,8 @@ def test_load_plugins_version_fail_skip(
 )
 def test_load_plugins_version_fail_no_skip(
     monkeypatch_plugin_test_packages: None,
-    cli_args: t.List[str],
-    inputs: t.List[str],
+    cli_args: list[str],
+    inputs: list[str],
     monkeypatch: pytest.MonkeyPatch,
     capsys: pytest.CaptureFixture[str],
 ) -> None:
@@ -534,7 +534,7 @@ def test_load_plugins_version_fail_no_skip(
 )
 def test_load_plugins_plugin_missing(
     monkeypatch_plugin_test_packages: None,
-    cli_args: t.List[str],
+    cli_args: list[str],
     capsys: pytest.CaptureFixture[str],
 ) -> None:
     """Test tmuxp load with plugins missing raise an error."""
