@@ -1,4 +1,5 @@
 """CLI tests for tmuxp shell."""
+
 import contextlib
 import io
 import pathlib
@@ -6,11 +7,13 @@ import subprocess
 import typing as t
 
 import pytest
-from libtmux.server import Server
 from libtmux.session import Session
 
 from tmuxp import cli, exc
 
+if t.TYPE_CHECKING:
+    from libtmux.server import Server
+
 
 class CLIShellFixture(t.NamedTuple):
     """Test fixture for tmuxp shell tests."""
@@ -19,13 +22,13 @@ class CLIShellFixture(t.NamedTuple):
     test_id: str
 
     # test params
-    cli_args: t.List[str]
-    inputs: t.List[t.Any]
-    env: t.Dict[str, str]
+    cli_args: list[str]
+    inputs: list[t.Any]
+    env: dict[str, str]
     expected_output: str
 
 
-TEST_SHELL_FIXTURES: t.List[CLIShellFixture] = [
+TEST_SHELL_FIXTURES: list[CLIShellFixture] = [
     CLIShellFixture(
         test_id="print-socket-name",
         cli_args=["-L{SOCKET_NAME}", "-c", "print(str(server.socket_name))"],
@@ -105,11 +108,11 @@ TEST_SHELL_FIXTURES: t.List[CLIShellFixture] = [
     ids=[test.test_id for test in TEST_SHELL_FIXTURES],
 )
 def test_shell(
-    cli_cmd: t.List[str],
+    cli_cmd: list[str],
     test_id: str,
-    cli_args: t.List[str],
-    inputs: t.List[t.Any],
-    env: t.Dict[str, str],
+    cli_args: list[str],
+    inputs: list[t.Any],
+    env: dict[str, str],
     expected_output: str,
     server: "Server",
     session: Session,
@@ -121,15 +124,15 @@ def test_shell(
     monkeypatch.setenv("HOME", str(tmp_path))
     window_name = "my_window"
     window = session.new_window(window_name=window_name)
-    window.split_window()
+    window.split()
 
-    assert window.attached_pane is not None
+    assert window.active_pane is not None
 
     template_ctx = {
         "SOCKET_NAME": server.socket_name,
         "SESSION_NAME": session.name,
         "WINDOW_NAME": window_name,
-        "PANE_ID": window.attached_pane.id,
+        "PANE_ID": window.active_pane.id,
         "SERVER_SOCKET_NAME": server.socket_name,
     }
 
@@ -153,7 +156,7 @@ def test_shell(
     ],
 )
 @pytest.mark.parametrize(
-    "cli_args,inputs,env,template_ctx,exception,message",
+    ("cli_args", "inputs", "env", "template_ctx", "exception", "message"),
     [
         (
             ["-LDoesNotExist", "-c", "print(str(server.socket_name))"],
@@ -193,14 +196,14 @@ def test_shell(
     ],
 )
 def test_shell_target_missing(
-    cli_cmd: t.List[str],
-    cli_args: t.List[str],
-    inputs: t.List[t.Any],
-    env: t.Dict[t.Any, t.Any],
-    template_ctx: t.Dict[str, str],
+    cli_cmd: list[str],
+    cli_args: list[str],
+    inputs: list[t.Any],
+    env: dict[t.Any, t.Any],
+    template_ctx: dict[str, str],
     exception: t.Union[
-        t.Type[exc.TmuxpException],
-        t.Type[subprocess.CalledProcessError],
+        type[exc.TmuxpException],
+        type[subprocess.CalledProcessError],
     ],
     message: str,
     socket_name: str,
@@ -214,7 +217,7 @@ def test_shell_target_missing(
     monkeypatch.setenv("HOME", str(tmp_path))
     window_name = "my_window"
     window = session.new_window(window_name=window_name)
-    window.split_window()
+    window.split()
 
     assert server.socket_name is not None
     assert session.name is not None
@@ -255,7 +258,7 @@ def test_shell_target_missing(
     ],
 )
 @pytest.mark.parametrize(
-    "cli_args,inputs,env,message",
+    ("cli_args", "inputs", "env", "message"),
     [
         (
             [
@@ -276,10 +279,10 @@ def test_shell_target_missing(
     ],
 )
 def test_shell_interactive(
-    cli_cmd: t.List[str],
-    cli_args: t.List[str],
-    inputs: t.List[t.Any],
-    env: t.Dict[str, str],
+    cli_cmd: list[str],
+    cli_args: list[str],
+    inputs: list[t.Any],
+    env: dict[str, str],
     message: str,
     server: "Server",
     session: Session,
@@ -291,15 +294,15 @@ def test_shell_interactive(
     monkeypatch.setenv("HOME", str(tmp_path))
     window_name = "my_window"
     window = session.new_window(window_name=window_name)
-    window.split_window()
+    window.split()
 
-    assert window.attached_pane is not None
+    assert window.active_pane is not None
 
     template_ctx = {
         "SOCKET_NAME": server.socket_name,
         "SESSION_NAME": session.name,
         "WINDOW_NAME": window_name,
-        "PANE_ID": window.attached_pane.id,
+        "PANE_ID": window.active_pane.id,
         "SERVER_SOCKET_NAME": server.socket_name,
     }
 
