@@ -1,4 +1,5 @@
 """Fixtures for tmuxp plugins for tmux version exceptions."""
+
 import typing as t
 
 from .test_plugin_helpers import MyTestTmuxpPlugin
@@ -11,7 +12,7 @@ class TmuxVersionFailMinPlugin(MyTestTmuxpPlugin):
     """Tmuxp plugin that fails when tmux below minimum version constraint."""
 
     def __init__(self) -> None:
-        config: "PluginTestConfigSchema" = {
+        config: PluginTestConfigSchema = {
             "plugin_name": "tmux-min-version-fail",
             "tmux_min_version": "1.8",
             "tmux_version": "1.7",
@@ -23,7 +24,7 @@ class TmuxVersionFailMaxPlugin(MyTestTmuxpPlugin):
     """Tmuxp plugin that fails when tmux above maximum version constraint."""
 
     def __init__(self) -> None:
-        config: "PluginTestConfigSchema" = {
+        config: PluginTestConfigSchema = {
             "plugin_name": "tmux-max-version-fail",
             "tmux_max_version": "3.0",
             "tmux_version": "3.5",
@@ -35,7 +36,7 @@ class TmuxVersionFailIncompatiblePlugin(MyTestTmuxpPlugin):
     """Tmuxp plugin that fails when tmux version constraint is invalid."""
 
     def __init__(self) -> None:
-        config: "PluginTestConfigSchema" = {
+        config: PluginTestConfigSchema = {
             "plugin_name": "tmux-incompatible-version-fail",
             "tmux_version_incompatible": ["2.3"],
             "tmux_version": "2.3",
