@@ -1,4 +1,5 @@
 """Fixtures for tmuxp plugins for tmuxp version exceptions."""
+
 import typing as t
 
 from .test_plugin_helpers import MyTestTmuxpPlugin
@@ -11,7 +12,7 @@ class TmuxpVersionFailMinPlugin(MyTestTmuxpPlugin):
     """Tmuxp plugin that fails when tmuxp below minimum version constraint."""
 
     def __init__(self) -> None:
-        config: "PluginTestConfigSchema" = {
+        config: PluginTestConfigSchema = {
             "plugin_name": "tmuxp-min-version-fail",
             "tmuxp_min_version": "1.7.0",
             "tmuxp_version": "1.6.3",
@@ -23,7 +24,7 @@ class TmuxpVersionFailMaxPlugin(MyTestTmuxpPlugin):
     """Tmuxp plugin that fails when tmuxp above maximum version constraint."""
 
     def __init__(self) -> None:
-        config: "PluginTestConfigSchema" = {
+        config: PluginTestConfigSchema = {
             "plugin_name": "tmuxp-max-version-fail",
             "tmuxp_max_version": "2.0.0",
             "tmuxp_version": "2.5",
@@ -35,7 +36,7 @@ class TmuxpVersionFailIncompatiblePlugin(MyTestTmuxpPlugin):
     """Tmuxp plugin that fails when tmuxp version constraint is invalid."""
 
     def __init__(self) -> None:
-        config: "PluginTestConfigSchema" = {
+        config: PluginTestConfigSchema = {
             "plugin_name": "tmuxp-incompatible-version-fail",
             "tmuxp_version_incompatible": ["1.5.0"],
             "tmuxp_version": "1.5.0",
